=== modified file 'Makefile.am'
--- Makefile.am	2010-03-23 08:23:32 +0000
+++ Makefile.am	2010-04-16 00:08:16 +0000
@@ -66,19 +66,7 @@
 EXTRA_DIST+=	${man_MANS}
 
 .PHONY: \
-	indent \
-	test
-
-
-# Target 'test' will run the regression test suite using the built server.
-#
-# If you are running in a shared environment, users can avoid clashing
-# port numbers by setting individual small numbers 1-100 to the
-# environment variable MTR_BUILD_THREAD. The script "test-run"
-# will then calculate the various port numbers it needs from this,
-# making sure each user use different ports.
-
-test: test-drizzle
+	indent
 
 doxygen:
 	doxygen Doxyfile

=== modified file 'config/lint-source.am'
--- config/lint-source.am	2009-12-04 19:01:26 +0000
+++ config/lint-source.am	2010-04-16 00:08:16 +0000
@@ -14,7 +14,7 @@
 clean-local: cleanlints
 
 
-check-local: linted ${srcdir}/config/lint-rules.am
+installcheck-local: linted ${srcdir}/config/lint-rules.am
 
 linted:
 

=== modified file 'config/pandora-plugin'
--- config/pandora-plugin	2010-04-01 17:45:30 +0000
+++ config/pandora-plugin	2010-04-16 00:08:16 +0000
@@ -22,21 +22,7 @@
 import datetime, time
 import subprocess
 
-top_srcdir='.'
-top_builddir='.'
-plugin_ini_fname='plugin.ini'
-plugin_list=[]
-plugin_am_file=None
-plugin_ac_file=None
-plugin_prefix=''
-plugin_suffix='_plugin'
-extra_cflags=''
-extra_cppflags=''
-extra_cxxflags=''
-root_plugin_dir='plugin'
-pkgplugindir='$(libdir)/drizzle'
-default_install='True'
-default_plugin_version=''
+from pandora_plugin_config import *
 
 class ChangeProtectedFile(object):
 
@@ -143,19 +129,21 @@
 """ % plugin)
   if plugin['headers'] != "":
     plugin_file.write("noinst_HEADERS = %(headers)s\n" % plugin)
+  if plugin['install_headers'] != "":
+    plugin_file.write("nobase_include_HEADERS += %(install_headers)s\n" % plugin)
   if plugin['testsuite']:
     if plugin.has_key('testsuitedir') and plugin['testsuitedir'] != "":
       plugin_file.write("EXTRA_DIST += %(testsuitedir)s\n" % plugin)
   plugin_file.write("""
-pkgplugin_LTLIBRARIES=%(pname)s.la
-%(pname)s_la_LDFLAGS=-avoid-version -rpath $(pkgplugindir) $(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
-%(pname)s_la_LIBADD=%(libs)s
-%(pname)s_la_DEPENDENCIES=%(libs)s
-%(pname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_DYNAMIC_PLUGIN -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR="%(author)s" -DPANDORA_MODULE_TITLE="%(title)s" -DPANDORA_MODULE_VERSION="%(version)s" -DPANDORA_MODULE_LICENSE=%(license)s %(cppflags)s
-%(pname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
-%(pname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
+pkgplugin_LTLIBRARIES=%(libname)s.la
+%(libname)s_la_LDFLAGS=-avoid-version -rpath $(pkgplugindir) $(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
+%(libname)s_la_LIBADD=%(libs)s
+%(libname)s_la_DEPENDENCIES=%(libs)s
+%(libname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_DYNAMIC_PLUGIN -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR='"%(author)s"' -DPANDORA_MODULE_TITLE='"%(title)s"' -DPANDORA_MODULE_VERSION='"%(version)s"' -DPANDORA_MODULE_LICENSE=%(license)s %(cppflags)s
+%(libname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
+%(libname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
 
-%(pname)s_la_SOURCES=%(sources)s
+%(libname)s_la_SOURCES=%(sources)s
 
 """ % plugin)
   plugin_am_file=os.path.join(plugin['rel_path'],'plugin.am')
@@ -165,7 +153,7 @@
 def write_external_plugin():
   """Return True if the plugin had changed."""
   plugin = read_plugin_ini('.')
-  expand_plugin_ini(plugin, '.')
+  expand_plugin_ini(plugin)
   plugin_file = ChangeProtectedFile('configure.ac')
   write_external_configure(plugin, plugin_file)
   result = plugin_file.close()
@@ -175,12 +163,33 @@
   result = plugin_file.close() or result
   return result
 
-def write_plugin(plugin_dir):
-  """Return True if the plugin had changed."""
-  plugin = read_plugin_ini(plugin_dir)
-  expand_plugin_ini(plugin, plugin_dir)
+def write_plugin(plugin, plugin_ini_list):
+  # Since this function is recursive, make sure we're not already in it.
+  if plugin.has_key('writing_status'):
+    if plugin['writing_status'] == 'done':
+      return
+    else:
+      print "Dependency loop detected with " % plugin['name']
+      exit(1)
+
+  plugin['writing_status'] = 'dependencies'
+
+  # Write all dependencies first to get around annoying automake bug
+  if plugin['dependency_list'] is not None:
+    for dependency in plugin['dependency_list']:
+      found = False
+      for find_plugin in plugin_ini_list:
+        if find_plugin['name'] == dependency:
+          found = True
+          write_plugin(find_plugin, plugin_ini_list)
+          break
+      if found is False:
+        print "Could not find dependency %s" % dependency
+        exit(1)
+
   write_plugin_ac(plugin, plugin_ac_file)
   write_plugin_am(plugin, plugin_am_file)
+  plugin['writing_status'] = 'done'
 
 def write_plugin_ac(plugin, plugin_ac):
   #
@@ -206,7 +215,7 @@
 dnl possible to disable it. Once it is disableable, we will make it non-static.
 with_%(name)s_plugin=yes
 pandora_builtin_list="_drizzled_%(name)s_plugin_,${pandora_builtin_list}"
-pandora_plugin_libs="${pandora_plugin_libs} \${top_builddir}/%(root_plugin_dir)s/%(pname)s.la"
+pandora_plugin_libs="${pandora_plugin_libs} \${top_builddir}/%(root_plugin_dir)s/%(libname)s.la"
 PANDORA_PLUGIN_DEP_LIBS="${PANDORA_PLUGIN_DEP_LIBS} %(plugin_dep_libs)s"
 
 """ % plugin)
@@ -281,23 +290,23 @@
     plugin_ac.write("      ])\n")
 
 
-def expand_plugin_ini(plugin, plugin_dir):
+def expand_plugin_ini(plugin):
     if plugin['name'] == "**OUT-OF-TREE**":
       print "Out of tree plugins require the name field to be specified in plugin.ini"
       sys.exit(1)
 
-    if plugin_dir == ".":
-      plugin['rel_path']= plugin_dir
+    if plugin['plugin_dir'] == ".":
+      plugin['rel_path']= plugin['plugin_dir']
       plugin['unconditional']=True
     else:
-      plugin['rel_path']= plugin_dir[len(top_srcdir)+len(os.path.sep):]
+      plugin['rel_path']= plugin['plugin_dir'][len(top_srcdir)+len(os.path.sep):]
       plugin['unconditional']=False
     # TODO: determine path to plugin dir relative to top_srcdir... append it to
     # source files if they don't already have it
     if plugin['sources'] == "":
       plugin['sources']="%s.cc" % plugin['name']
     new_sources=""
-    if plugin_dir != ".":
+    if plugin['plugin_dir'] != ".":
       for src in plugin['sources'].split():
         if not src.startswith(plugin['rel_path']):
           src= os.path.join(plugin['rel_path'], src)
@@ -309,7 +318,7 @@
     plugin['main_source']= plugin['sources'].split()[0]
     
     new_headers=""
-    if plugin_dir != ".":
+    if plugin['plugin_dir'] != ".":
       for header in plugin['headers'].split():
         if not header.startswith(plugin['rel_path']):
           header= os.path.join(plugin['rel_path'], header)
@@ -319,6 +328,17 @@
     if new_headers != "":
       plugin['headers']= new_headers
     
+    new_install_headers=""
+    if plugin['plugin_dir'] != ".":
+      for header in plugin['install_headers'].split():
+        if not header.startswith(plugin['rel_path']):
+          header= os.path.join(plugin['rel_path'], header)
+          new_install_headers= "%s %s" % (new_install_headers, header)
+    else:
+      new_install_headers= " ".join(plugin['install_headers'].split())
+    if new_install_headers != "":
+      plugin['install_headers']= new_install_headers
+    
     # Make a yes/no version for autoconf help messages
     if plugin['load_by_default']:
       plugin['default_yesno']="yes"
@@ -357,6 +377,7 @@
     plugin_file= os.path.join(plugin_dir,plugin_ini_fname)
     plugin_defaults= dict(sources="",
                           headers="",
+                          install_headers="",
                           cflags="",
                           cppflags="",
                           cxxflags="",
@@ -370,10 +391,13 @@
                           load_by_default="False",
                           disabled="False",
                           static="False",
+                          dependencies="",
+                          dependency_aliases="",
                           install=default_install)
     parser=ConfigParser.ConfigParser(defaults= plugin_defaults)
     parser.read(plugin_file)
     plugin=dict(parser.items('plugin'))
+    plugin['plugin_dir'] = plugin_dir
     if plugin_dir == '.':
       if not plugin.has_key('url'):
         print "External Plugins are required to specifiy a url"
@@ -412,12 +436,35 @@
     plugin['cppflags']+= extra_cppflags
     plugin['cxxflags']+= extra_cxxflags
 
-    plugin['pname']= "lib%s%s%s" % (plugin_prefix, plugin['name'], plugin_suffix)
+    plugin['libname']= "lib%s%s%s" % (plugin_prefix, plugin['name'], plugin_suffix)
+    if force_lowercase_libname:
+      plugin['libname']= plugin['libname'].lower()
+
     plugin['root_plugin_dir']= root_plugin_dir
     plugin['plugin_prefix']= plugin_prefix
     plugin['plugin_suffix']= plugin_suffix
     plugin['pkgplugindir']= pkgplugindir
 
+    # Dependencies must have a module but dependency aliases are simply added
+    # to the variable passed during compile.
+    plugin['dependencies'] = plugin['dependencies'].replace(' ', '')
+    plugin['dependency_aliases'] = plugin['dependency_aliases'].replace(' ', '')
+    if plugin['dependencies'] == '':
+      plugin['dependency_list'] = None
+      plugin['dependencies'] = plugin['dependency_aliases']
+    else:
+      plugin['dependency_list'] = plugin['dependencies'].split(',')
+      if plugin['dependency_aliases'] != '':
+        plugin['dependencies'] = ','.join([plugin['dependencies'], plugin['dependency_aliases']])
+
+# Libtool is going to expand:
+#      -DPANDORA_MODULE_AUTHOR='"Padraig O'"'"'Sullivan"'
+# to:
+# "-DPANDORA_MODULE_AUTHOR=\"Padraig O'Sullivan\""
+# So we have to replace internal ''s to '"'"'
+    for key in ('author','title','description','version'):
+      plugin[key]=plugin[key].replace('"','\\"')
+      plugin[key]=plugin[key].replace("'","'\"'\"'")
     return plugin
 
 
@@ -438,6 +485,8 @@
 """ % plugin)
   if plugin['headers'] != "":
     plugin_am.write("noinst_HEADERS += %(headers)s\n" % plugin)
+  if plugin['install_headers'] != "":
+    plugin_am.write("nobase_include_HEADERS += %(install_headers)s\n" % plugin)
   if plugin['testsuite']:
     if plugin.has_key('testsuitedir') and plugin['testsuitedir'] != "":
       plugin_am.write("EXTRA_DIST += %(rel_path)s/%(testsuitedir)s\n" % plugin)
@@ -446,16 +495,16 @@
 %(root_plugin_dir)s_%(plugin_prefix)s%(name)s_dir=${top_srcdir}/%(rel_path)s
 EXTRA_DIST += %(rel_path)s/plugin.ini
 if %(build_conditional_tag)s
-  noinst_LTLIBRARIES+=%(root_plugin_dir)s/%(pname)s.la
-  %(root_plugin_dir)s_%(pname)s_la_LIBADD=%(libs)s
-  %(root_plugin_dir)s_%(pname)s_la_DEPENDENCIES=%(libs)s
-  %(root_plugin_dir)s_%(pname)s_la_LDFLAGS=$(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
-  %(root_plugin_dir)s_%(pname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR="%(author)s" -DPANDORA_MODULE_TITLE="%(title)s" -DPANDORA_MODULE_VERSION="%(version)s" -DPANDORA_MODULE_LICENSE=%(license)s %(cppflags)s
-  %(root_plugin_dir)s_%(pname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
-  %(root_plugin_dir)s_%(pname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
+  noinst_LTLIBRARIES+=%(root_plugin_dir)s/%(libname)s.la
+  %(root_plugin_dir)s_%(libname)s_la_LIBADD=%(libs)s
+  %(root_plugin_dir)s_%(libname)s_la_DEPENDENCIES=%(libs)s
+  %(root_plugin_dir)s_%(libname)s_la_LDFLAGS=$(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
+  %(root_plugin_dir)s_%(libname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR='"%(author)s"' -DPANDORA_MODULE_TITLE='"%(title)s"' -DPANDORA_MODULE_VERSION='"%(version)s"' -DPANDORA_MODULE_LICENSE=%(license)s -DPANDORA_MODULE_DEPENDENCIES='"%(dependencies)s"' %(cppflags)s
+  %(root_plugin_dir)s_%(libname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
+  %(root_plugin_dir)s_%(libname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
 
-  %(root_plugin_dir)s_%(pname)s_la_SOURCES=%(sources)s
-  PANDORA_DYNAMIC_LDADDS+=${top_builddir}/%(root_plugin_dir)s/%(pname)s.la
+  %(root_plugin_dir)s_%(libname)s_la_SOURCES=%(sources)s
+  PANDORA_DYNAMIC_LDADDS+=${top_builddir}/%(root_plugin_dir)s/%(libname)s.la
 endif
 """ % plugin)
   else:
@@ -463,15 +512,15 @@
 %(root_plugin_dir)s_%(plugin_prefix)s%(name)s_dir=${top_srcdir}/%(rel_path)s
 EXTRA_DIST += %(rel_path)s/plugin.ini
 if %(build_conditional_tag)s
-  %(library_type)s_LTLIBRARIES+=%(root_plugin_dir)s/%(pname)s.la
-  %(root_plugin_dir)s_%(pname)s_la_LDFLAGS=-avoid-version -rpath $(pkgplugindir) $(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
-  %(root_plugin_dir)s_%(pname)s_la_LIBADD=%(libs)s
-  %(root_plugin_dir)s_%(pname)s_la_DEPENDENCIES=%(libs)s
-  %(root_plugin_dir)s_%(pname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_DYNAMIC_PLUGIN -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR="%(author)s" -DPANDORA_MODULE_TITLE="%(title)s" -DPANDORA_MODULE_VERSION="%(version)s" -DPANDORA_MODULE_LICENSE=%(license)s %(cppflags)s
-  %(root_plugin_dir)s_%(pname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
-  %(root_plugin_dir)s_%(pname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
+  %(library_type)s_LTLIBRARIES+=%(root_plugin_dir)s/%(libname)s.la
+  %(root_plugin_dir)s_%(libname)s_la_LDFLAGS=-avoid-version -rpath $(pkgplugindir) $(AM_LDFLAGS) %(ldflags)s $(GCOV_LIBS)
+  %(root_plugin_dir)s_%(libname)s_la_LIBADD=%(libs)s
+  %(root_plugin_dir)s_%(libname)s_la_DEPENDENCIES=%(libs)s
+  %(root_plugin_dir)s_%(libname)s_la_CPPFLAGS=$(AM_CPPFLAGS) -DPANDORA_DYNAMIC_PLUGIN -DPANDORA_MODULE_NAME=%(name)s -DPANDORA_MODULE_AUTHOR='"%(author)s"' -DPANDORA_MODULE_TITLE='"%(title)s"' -DPANDORA_MODULE_VERSION='"%(version)s"' -DPANDORA_MODULE_LICENSE=%(license)s -DPANDORA_MODULE_DEPENDENCIES='"%(dependencies)s"' %(cppflags)s
+  %(root_plugin_dir)s_%(libname)s_la_CXXFLAGS=$(AM_CXXFLAGS) %(cxxflags)s
+  %(root_plugin_dir)s_%(libname)s_la_CFLAGS=$(AM_CFLAGS) %(cflags)s
 
-  %(root_plugin_dir)s_%(pname)s_la_SOURCES=%(sources)s
+  %(root_plugin_dir)s_%(libname)s_la_SOURCES=%(sources)s
 endif
 """ % plugin)
   plugin_am_file=os.path.join(plugin['rel_path'],'plugin.am')
@@ -539,7 +588,8 @@
 EXTRA_DIST += \
 	config/pandora-plugin.am \
 	config/pandora-plugin.ac \
-	config/pandora-plugin
+	config/pandora-plugin \
+	config/pandora_plugin_config.py
 
 
 # Seed the list of plugin LDADDS which plugins may extend.
@@ -571,8 +621,16 @@
   for plugin_dir in plugin_list:
     plugin_am_file.write("\\\n\t%s/plugin.ini " % plugin_dir)
   plugin_am_file.write("\n\tcd ${top_srcdir} && python config/pandora-plugin write\n")
+  plugin_ini_list=[]
+
+  # Load all plugin.ini files first so we can do dependency tracking.
   for plugin_dir in plugin_list:
-    write_plugin(plugin_dir)
+    plugin = read_plugin_ini(plugin_dir)
+    expand_plugin_ini(plugin)
+    plugin_ini_list.append(plugin)
+
+  for plugin in plugin_ini_list:
+    write_plugin(plugin, plugin_ini_list)
 
 if plugin_am_file is not None:
   plugin_am_file.close()

=== added file 'config/pandora_plugin_config.py'
--- config/pandora_plugin_config.py	1970-01-01 00:00:00 +0000
+++ config/pandora_plugin_config.py	2010-04-16 00:08:16 +0000
@@ -0,0 +1,33 @@
+#!/usr/bin/python
+
+#  Copyright (C) 2009 Sun Microsystems
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; version 2 of the License.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+top_srcdir='.'
+top_builddir='.'
+plugin_ini_fname='plugin.ini'
+plugin_list=[]
+plugin_am_file=None
+plugin_ac_file=None
+plugin_prefix=''
+plugin_suffix='_plugin'
+extra_cflags=''
+extra_cppflags=''
+extra_cxxflags=' -DBUILDING_DRIZZLE'
+root_plugin_dir='plugin'
+pkgplugindir='$(libdir)/drizzle'
+default_install='True'
+default_plugin_version=''
+force_lowercase_libname=True

=== modified file 'm4/pandora_canonical.m4'
--- m4/pandora_canonical.m4	2010-04-01 17:45:30 +0000
+++ m4/pandora_canonical.m4	2010-04-16 00:08:16 +0000
@@ -4,7 +4,7 @@
 dnl with or without modifications, as long as this notice is preserved.
 
 dnl Which version of the canonical setup we're using
-AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.118])
+AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.121])
 
 AC_DEFUN([PANDORA_FORCE_DEPEND_TRACKING],[
   AC_ARG_ENABLE([fat-binaries],

=== added file 'm4/pandora_have_libgtest.m4'
--- m4/pandora_have_libgtest.m4	1970-01-01 00:00:00 +0000
+++ m4/pandora_have_libgtest.m4	2010-04-16 00:08:16 +0000
@@ -0,0 +1,44 @@
+dnl Copyright (C) 2010 Monty Taylor
+dnl This file is free software; Monty Taylor
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+
+AC_DEFUN([_PANDORA_SEARCH_LIBGTEST],[
+  AC_REQUIRE([AC_LIB_PREFIX])
+
+  dnl --------------------------------------------------------------------
+  dnl  Check for libgtest
+  dnl --------------------------------------------------------------------
+
+  AC_ARG_ENABLE([libgtest],
+    [AS_HELP_STRING([--disable-libgtest],
+      [Build with libgtest support @<:@default=on@:>@])],
+    [ac_enable_libgtest="$enableval"],
+    [ac_enable_libgtest="yes"])
+
+  AS_IF([test "x$ac_enable_libgtest" = "xyes"],[
+    AC_LANG_PUSH(C++)
+    AC_LIB_HAVE_LINKFLAGS(gtest,,[
+      #include <gtest/gtest.h>
+TEST(pandora_test_libgtest, PandoraTest)
+{
+  ASSERT_EQ(1, 1);
+}
+    ],[])
+    AC_LANG_POP()
+  ],[
+    ac_cv_libgtest="no"
+  ])
+
+  AM_CONDITIONAL(HAVE_LIBGTEST, [test "x${ac_cv_libgtest}" = "xyes"])
+])
+
+AC_DEFUN([PANDORA_HAVE_LIBGTEST],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBGTEST])
+])
+
+AC_DEFUN([PANDORA_REQUIRE_LIBGTEST],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBGTEST])
+  AS_IF([test "x${ac_cv_libgtest}" = "xno"],
+    AC_MSG_ERROR([libgtest is required for ${PACKAGE}]))
+])

=== modified file 'm4/pandora_have_libmemcached.m4'
--- m4/pandora_have_libmemcached.m4	2010-04-06 23:15:47 +0000
+++ m4/pandora_have_libmemcached.m4	2010-04-16 00:08:16 +0000
@@ -62,7 +62,7 @@
     ],[
       AS_IF([test "x$1" != "x"],[
         pandora_need_libmemcached_version=`echo "$1" | perl -nle '/(\d+)\.(\d+)/; printf "%d%0.3d000", $[]1, $[]2 ;'`
-        AS_IF([test "x${pandora_need_libmemcached_version}" = "x00039000"],[
+        AS_IF([test "x${pandora_need_libmemcached_version}" = "x0000000"],[
           pandora_cv_recent_libmemcached=yes
         ],[
           AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[

=== added file 'm4/pandora_have_sasl.m4'
--- m4/pandora_have_sasl.m4	1970-01-01 00:00:00 +0000
+++ m4/pandora_have_sasl.m4	2010-04-16 00:08:16 +0000
@@ -0,0 +1,133 @@
+dnl  Copyright (C) 2009 Sun Microsystems
+dnl This file is free software; Sun Microsystems
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+
+AC_DEFUN([_PANDORA_SEARCH_SASL],[
+  AC_REQUIRE([AC_LIB_PREFIX])
+
+  dnl --------------------------------------------------------------------
+  dnl  Check for sasl
+  dnl --------------------------------------------------------------------
+  AC_ARG_ENABLE([sasl],
+    [AS_HELP_STRING([--disable-sasl],
+      [Build with sasl support @<:@default=on@:>@])],
+    [ac_enable_sasl="$enableval"],
+    [ac_enable_sasl="yes"])
+
+  AS_IF([test "x$ac_enable_sasl" = "xyes"],
+    [
+      AC_LIB_HAVE_LINKFLAGS(sasl,,[
+        #include <stdlib.h>
+        #include <sasl/sasl.h>
+      ],[
+        sasl_server_init(NULL, NULL);
+      ])
+
+      AS_IF([test "x${ac_cv_libsasl}" != "xyes" ],
+            [
+              AC_LIB_HAVE_LINKFLAGS(sasl2,,[
+                #include <stdlib.h>
+                #include <sasl/sasl.h>
+              ],[
+                sasl_server_init(NULL, NULL);
+              ])
+              HAVE_LIBSASL="$HAVE_LIBSASL2"
+              LIBSASL="$LIBSASL2"
+              LIBSASL_PREFIX="$LIBSASL2_PREFIX"
+	      LTLIBSASL="$LT_LIBSASL2"
+            ])
+    ])
+
+  AS_IF([test "x${ac_cv_libsasl}" = "xyes" -o "x${ac_cv_libsasl2}" = "xyes"],
+        [ac_cv_sasl=yes],
+        [ac_cv_sasl=no])
+
+  AM_CONDITIONAL(HAVE_LIBSASL, [test "x${ac_cv_libsasl}" = "xyes"])
+  AM_CONDITIONAL(HAVE_LIBSASL2, [test "x${ac_cv_libsasl2}" = "xyes"])
+  AM_CONDITIONAL(HAVE_SASL, [test "x${ac_cv_sasl}" = "xyes"])
+])
+
+AC_DEFUN([PANDORA_HAVE_SASL],[
+  AC_REQUIRE([_PANDORA_SEARCH_SASL])
+])
+
+AC_DEFUN([PANDORA_REQUIRE_SASL],[
+  AC_REQUIRE([_PANDORA_SEARCH_SASL])
+  AS_IF([test "x${ac_cv_sasl}" = "xno"],
+    AC_MSG_ERROR([SASL (libsasl or libsasl2) is required for ${PACKAGE}]))
+])
+
+AC_DEFUN([_PANDORA_SEARCH_LIBSASL],[
+  AC_REQUIRE([AC_LIB_PREFIX])
+
+  dnl --------------------------------------------------------------------
+  dnl  Check for libsasl
+  dnl --------------------------------------------------------------------
+
+  AC_ARG_ENABLE([libsasl],
+    [AS_HELP_STRING([--disable-libsasl],
+      [Build with libsasl support @<:@default=on@:>@])],
+    [ac_enable_libsasl="$enableval"],
+    [ac_enable_libsasl="yes"])
+
+  AS_IF([test "x$ac_enable_libsasl" = "xyes"],[
+    AC_LIB_HAVE_LINKFLAGS(sasl,,[
+      #include <stdlib.h>
+      #include <sasl/sasl.h>
+    ],[
+      sasl_server_init(NULL, NULL);
+    ])
+  ],[
+    ac_cv_libsasl="no"
+  ])
+
+  AM_CONDITIONAL(HAVE_LIBSASL, [test "x${ac_cv_libsasl}" = "xyes"])
+])
+
+AC_DEFUN([PANDORA_HAVE_LIBSASL],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBSASL])
+])
+
+AC_DEFUN([PANDORA_REQUIRE_LIBSASL],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBSASL])
+  AS_IF([test "x${ac_cv_libsasl}" = "xno"],
+    AC_MSG_ERROR([libsasl is required for ${PACKAGE}]))
+])
+
+AC_DEFUN([_PANDORA_SEARCH_LIBSASL2],[
+  AC_REQUIRE([AC_LIB_PREFIX])
+
+  dnl --------------------------------------------------------------------
+  dnl  Check for libsasl2
+  dnl --------------------------------------------------------------------
+
+  AC_ARG_ENABLE([libsasl2],
+    [AS_HELP_STRING([--disable-libsasl2],
+      [Build with libsasl2 support @<:@default=on@:>@])],
+    [ac_enable_libsasl2="$enableval"],
+    [ac_enable_libsasl2="yes"])
+
+  AS_IF([test "x$ac_enable_libsasl2" = "xyes"],[
+    AC_LIB_HAVE_LINKFLAGS(sasl2,,[
+      #include <stdlib.h>
+      #include <sasl2/sasl2.h>
+    ],[
+      sasl2_server_init(NULL, NULL);
+    ])
+  ],[
+    ac_cv_libsasl2="no"
+  ])
+
+  AM_CONDITIONAL(HAVE_LIBSASL2, [test "x${ac_cv_libsasl2}" = "xyes"])
+])
+
+AC_DEFUN([PANDORA_HAVE_LIBSASL2],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBSASL2])
+])
+
+AC_DEFUN([PANDORA_REQUIRE_LIBSASL2],[
+  AC_REQUIRE([_PANDORA_SEARCH_LIBSASL2])
+  AS_IF([test "x${ac_cv_libsasl2}" = "xno"],
+    AC_MSG_ERROR([libsasl2 is required for ${PACKAGE}]))
+])

=== modified file 'm4/pandora_platform.m4'
--- m4/pandora_platform.m4	2010-01-02 04:53:48 +0000
+++ m4/pandora_platform.m4	2010-04-16 00:08:16 +0000
@@ -34,6 +34,8 @@
     ;;
   esac
 
+  PANDORA_OPTIMIZE_BITFIELD=1
+
   case "$target_os" in
     *linux*)
     TARGET_LINUX="true"
@@ -47,6 +49,7 @@
       ;;
     *solaris*)
       TARGET_SOLARIS="true"
+      PANDORA_OPTIMIZE_BITFIELD=0
       AC_SUBST(TARGET_SOLARIS)
       AC_DEFINE([TARGET_OS_SOLARIS], [1], [Whether we are building for Solaris])
       ;;
@@ -60,6 +63,8 @@
       ;;
   esac
 
+  AC_SUBST(PANDORA_OPTIMIZE_BITFIELD)
+
   AC_CHECK_DECL([__SUNPRO_C], [SUNCC="yes"], [SUNCC="no"])
   AC_CHECK_DECL([__ICC], [INTELCC="yes"], [INTELCC="no"])
 

=== modified file 'm4/pandora_warnings.m4'
--- m4/pandora_warnings.m4	2010-01-26 00:57:12 +0000
+++ m4/pandora_warnings.m4	2010-04-16 00:08:16 +0000
@@ -146,6 +146,8 @@
         BASE_WARNINGS_FULL="-Wformat=2 ${W_CONVERSION} -Wstrict-aliasing"
         CC_WARNINGS_FULL="-Wswitch-default -Wswitch-enum -Wwrite-strings"
         CXX_WARNINGS_FULL="-Weffc++ -Wold-style-cast"
+        NO_OLD_STYLE_CAST="-Wno-old-style-cast"
+        NO_EFF_CXX="-Wno-effc++"
       ],[
         BASE_WARNINGS_FULL="-Wformat ${NO_STRICT_ALIASING}"
       ])
@@ -342,6 +344,8 @@
   AC_SUBST(NO_UNREACHED)
   AC_SUBST(NO_SHADOW)
   AC_SUBST(NO_STRICT_ALIASING)
+  AC_SUBST(NO_EFF_CXX)
+  AC_SUBST(NO_OLD_STYLE_CAST)
   AC_SUBST(PROTOSKIP_WARNINGS)
   AC_SUBST(INNOBASE_SKIP_WARNINGS)
   AC_SUBST(NO_WERROR)

=== modified file 'tests/include.am'
--- tests/include.am	2010-02-26 16:55:54 +0000
+++ tests/include.am	2010-04-16 00:08:16 +0000
@@ -52,7 +52,7 @@
 	${srcdir}/tests/lib/*.pl \
 	${srcdir}/tests/lib/My/*.pm
 
-check: test-drizzle
+check-local: test-drizzle
 
 # dtr - a shortcut for executing test-run.pl
 tests/dtr:
@@ -86,7 +86,7 @@
 # will then calculate the various port numbers it needs from this,
 # making sure each user use different ports.
 
-test: test-drizzle
+test: check
 
 # Please keep the list of tests in alphabetical order for ease of
 # maintenance and verification

